@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2015-03-10'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-03-15'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -56,6 +56,30 @@ sub _process_hl {
         my $p = $hl->todo_priority;
         return unless defined($p) && $args->{priority} eq $p;
     }
+    if (defined $args->{minimum_priority}) {
+        my $p = $hl->todo_priority;
+
+        if (defined $p) {
+            my $cmp = $hl->document->cmp_priorities(
+                $p, $args->{minimum_priority});
+            return if defined($cmp) && $cmp > 0;
+            return if !defined($cmp) && !$args->{with_unknown_priority};
+        } else {
+            return unless $args->{with_unknown_priority};
+        }
+    }
+    if (defined $args->{maximum_priority}) {
+        my $p = $hl->todo_priority;
+
+        if (defined $p) {
+            my $cmp = $hl->document->cmp_priorities(
+                $p, $args->{maximum_priority});
+            return if defined($cmp) && $cmp < 0;
+            return if !defined($cmp) && !$args->{with_unknown_priority};
+        } else {
+            return unless $args->{with_unknown_priority};
+        }
+    }
 
     my $ats = $hl->get_active_timestamp;
     my $days;
@@ -225,6 +249,45 @@ _
             summary => 'Only show todo items that have this priority',
             tags => ['filter'],
         },
+        minimum_priority => {
+            schema => ['str'],
+            summary => 'Only show todo items that have at least this priority',
+            tags => ['filter'],
+            description => <<'_',
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the `#+PRIORITIES` setting.
+
+_
+            links => ['maximum_priority'],
+        },
+        maximum_priority => {
+            schema => ['str'],
+            summary => 'Only show todo items that have at most this priority',
+            tags => ['filter'],
+            description => <<'_',
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the `#+PRIORITIES` setting.
+
+_
+            links => ['minimum_priority'],
+        },
+        with_unknown_priority => {
+            schema => ['bool'],
+            summary => 'Also show items with no/unknown priority',
+            tags => ['filter'],
+            description => <<'_',
+
+Relevant only when used with `minimum_priority` and/or `maximum_priority`.
+
+If this option is turned on, todo items that does not have any priority or have
+unknown priorities will *still* be included. Otherwise they will not be
+included.
+
+_
+            links => ['minimum_priority', 'maximum_priority'],
+        },
         time_zone => {
             schema => ['str'],
             summary => 'Will be passed to parser\'s options',
@@ -362,7 +425,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.24 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-10.
+This document describes version 0.25 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-15.
 
 =head1 SYNOPSIS
 
@@ -433,6 +496,20 @@ Only show headlines that have the specified tags.
 
 Only show headlines that don't have the specified tags.
 
+=item * B<maximum_priority> => I<str>
+
+Only show todo items that have at most this priority.
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the C<#+PRIORITIES> setting.
+
+=item * B<minimum_priority> => I<str>
+
+Only show todo items that have at least this priority.
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the C<#+PRIORITIES> setting.
+
 =item * B<priority> => I<str>
 
 Only show todo items that have this priority.
@@ -473,6 +550,16 @@ object, remember to set the correct time zone.
 
 Only show headlines that are todos.
 
+=item * B<with_unknown_priority> => I<bool>
+
+Also show items with no/unknown priority.
+
+Relevant only when used with C<minimum_priority> and/or C<maximum_priority>.
+
+If this option is turned on, todo items that does not have any priority or have
+unknown priorities will I<still> be included. Otherwise they will not be
+included.
+
 =back
 
 Returns an enveloped result (an array).
