@@ -1,7 +1,7 @@
 package App::ListOrgTodos;
 
-our $DATE = '2015-03-10'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-03-15'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010;
 use strict;
@@ -55,7 +55,7 @@ App::ListOrgTodos - List all todo items in all Org files
 
 =head1 VERSION
 
-This document describes version 0.24 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2015-03-10.
+This document describes version 0.25 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2015-03-15.
 
 =head1 SYNOPSIS
 
@@ -126,6 +126,20 @@ Only show headlines that have the specified tags.
 
 Only show headlines that don't have the specified tags.
 
+=item * B<maximum_priority> => I<str>
+
+Only show todo items that have at most this priority.
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the C<#+PRIORITIES> setting.
+
+=item * B<minimum_priority> => I<str>
+
+Only show todo items that have at least this priority.
+
+Note that the default priority list is [A, B, C] (A being the highest) and it
+can be customized using the C<#+PRIORITIES> setting.
+
 =item * B<priority> => I<str>
 
 Only show todo items that have this priority.
@@ -162,6 +176,16 @@ Assume today's date.
 You can provide Unix timestamp or DateTime object. If you provide a DateTime
 object, remember to set the correct time zone.
 
+=item * B<with_unknown_priority> => I<bool>
+
+Also show items with no/unknown priority.
+
+Relevant only when used with C<minimum_priority> and/or C<maximum_priority>.
+
+If this option is turned on, todo items that does not have any priority or have
+unknown priorities will I<still> be included. Otherwise they will not be
+included.
+
 =back
 
 Returns an enveloped result (an array).
